import time

from colour_printing import log, Switch, cprint, Back, Fore, Mode

log.info("hello world!")
# Switch.signal=False #关闭

# Switch.filter.append('SUCCESS') #过滤

log.error("hello world!")
log.success("hello world!")


log.warn("hello world!")
log.debug("hello world!")
# 颜料
cprint('default')
cprint('hello', fore=Fore.RED)



from colour_printing.custom import ColourPrint, Back, Fore, Mode
from colour_printing import cprint


class MyColour(ColourPrint):
    def custom(self):
        self.test = self.Markers('test')\
            .flag_style(fore=Fore.CYAN)\
            .time_style(mode=Mode.UNDERLINE)\
            .message_style(fore=Fore.YELLOW)


echo = MyColour()
cprint(echo, fore=Fore.BLUE, mode=Mode.BOLD)
echo.test('hello world!')



from colour_printing.custom.style import setting, Fore, Mode


def cprint(*args, **kwargs):
    """
    :param args: 字符
    :param kwargs: 颜色参数
    :return:  彩色字符
    """
    if kwargs:
        mode = kwargs.get('mode')
        fore = kwargs.get('fore')
        back = kwargs.get('back')
    else:
        mode = Mode.BOLD
        fore = Fore.CYAN
        back = ''
    style = setting(mode=mode, fore=fore, back=back)
    str_temp = []
    for s in args:
        str_temp.append(f'{style[0]}{s}{style[1]}')
    print(*str_temp)



from colour_printing.custom.markers import Markers
from colour_printing.custom.style import Back, Mode, Fore

default_info = "info"
default_warn = "warn"
default_success = "success"
default_error = "error"
default_debug = "debug"


class ColourPrint:
    Markers = Markers

    def __init__(self):
        self.__default_setting()

    def __init_subclass__(cls, **kwargs):
        cls.custom(cls)

    def custom(self):
        e = '''
        Custom styles need to override this method ! 
        #for example : 
        #    self.debug = self.Markers('debug').flag_style(mode=Mode.BOLD).time_style(...'''
        raise NotImplementedError(e)

    def __default_setting(self):
        self.info = Markers(default_info) \
            .flag_style(mode=Mode.INVERT, fore=Fore.BLUE).time_style(fore=Fore.CYAN).message_style(
            fore=Fore.BLUE)

        self.warn = Markers(default_warn) \
            .flag_style(mode=Mode.INVERT, fore=Fore.YELLOW).time_style(fore=Fore.CYAN).message_style(
            fore=Fore.YELLOW)

        self.success = Markers(default_success) \
            .flag_style(mode=Mode.INVERT, fore=Fore.GREEN).time_style(fore=Fore.CYAN).message_style(
            fore=Fore.GREEN)

        self.error = Markers(default_error) \
            .flag_style(mode=Mode.INVERT, fore=Fore.RED).time_style(fore=Fore.CYAN).message_style(
            fore=Fore.RED)

        self.debug = Markers(default_debug) \
            .flag_style(mode=Mode.INVERT, fore=Fore.PURPLE).time_style(fore=Fore.CYAN).message_style(
            fore=Fore.PURPLE)

    def __str__(self):
        return """
@'fore': # 前景色         @'back':# 背景              @'mode':# 显示模式
        'black': 黑色            'black':  黑色              'normal': 终端默认设置
        'red': 红色              'red':  红色                'bold':  高亮显示
        'green': 绿色            'green': 绿色               'underline':  使用下划线
        'yellow': 黄色           'yellow': 黄色              'blink': 闪烁
        'blue':  蓝色            'blue':  蓝色               'invert': 反白显示
        'purple':  紫红色        'purple':  紫红色            'hide': 不可见
        'cyan':  青蓝色          'cyan':  青蓝色
        'white':  白色           'white':  白色
            """


log = ColourPrint()
